==> conf_ini_g-2023.5-py3-none-any.whl: conf_ini_g/specification/parameter/annotation.py <==
# Copyright CNRS/Inria/UNS
# Contributor(s): Eric Debreuve (since 2021)
#
# eric.debreuve@cnrs.fr
#
# This software is governed by the CeCILL  license under French law and
# abiding by the rules of distribution of free software.  You can  use,
# modify and/ or redistribute the software under the terms of the CeCILL
# license as circulated by CEA, CNRS and INRIA at the following URL
# "http://www.cecill.info".
#
# As a counterpart to the access to the source code and  rights to copy,
# modify and redistribute granted by the license, users are provided only
# with a limited warranty  and the software's author,  the holder of the
# economic rights,  and the successive licensors  have only  limited
# liability.
#
# In this respect, the user's attention is drawn to the risks associated
# with loading,  using,  modifying and/or developing or reproducing the
# software by the user in light of its specific status of free software,
# that may mean  that it is complicated to manipulate,  and  that  also
# therefore means  that it is reserved for developers  and  experienced
# professionals having in-depth computer knowledge. Users are therefore
# encouraged to load and test the software's suitability as regards their
# requirements in conditions enabling the security of their systems and/or
# data to be ensured and,  more generally, to use and operate it in the
# same conditions as regards security.
#
# The fact that you are presently reading this means that you have had
# knowledge of the CeCILL license and that you accept its terms.

import dataclasses as dtcl
from typing import Any, ClassVar, Sequence

from rich.text import Text as text_t

from conf_ini_g.standard.str_extension import AlignedOnSeparator
from conf_ini_g.standard.type_extension import NameValueTypeAsRichStr, TypeAsRichStr


py_type_options_h = type | tuple[type, ...]


@dtcl.dataclass(repr=False, eq=False)
class annotation_t:
    VALID_PY_TYPES: ClassVar[py_type_options_h] = None

    def Issues(self, py_type: type, /) -> list[str]:
        """"""
        valid_types = self.__class__.VALID_PY_TYPES
        if (isinstance(valid_types, Sequence) and (py_type in valid_types)) or (
            py_type is valid_types
        ):
            return []

        return [
            f'{py_type}: Invalid Python type for annotation "{self.__class__.__name__}"; '
            f"Expected={valid_types}."
        ]

    def ValueIsCompliant(self, _: Any, /) -> bool:
        """"""
        return True

    def __str__(self) -> str:
        """"""
        return text_t.from_markup(self.__rich__()).plain

    def __rich__(self) -> str:
        """"""
        output = [TypeAsRichStr(self)]

        if isinstance(self.__class__.VALID_PY_TYPES, Sequence):
            output.append(
                f"    [blue]Valid types[/]@=@{str(self.__class__.VALID_PY_TYPES)[1:-1]}"
            )

        names = (_fld.name for _fld in dtcl.fields(self))
        for name in names:
            value = getattr(self, name)
            output.append(f"    {NameValueTypeAsRichStr(name, value, separator='@=@')}")

        output = AlignedOnSeparator(output, "@=@", " = ")

        return "\n".join(output)

==> conf_ini_g-2023.8-py3-none-any.whl: conf_ini_g/specification/parameter/annotation.py <==
# Copyright CNRS/Inria/UNS
# Contributor(s): Eric Debreuve (since 2021)
#
# eric.debreuve@cnrs.fr
#
# This software is governed by the CeCILL  license under French law and
# abiding by the rules of distribution of free software.  You can  use,
# modify and/ or redistribute the software under the terms of the CeCILL
# license as circulated by CEA, CNRS and INRIA at the following URL
# "http://www.cecill.info".
#
# As a counterpart to the access to the source code and  rights to copy,
# modify and redistribute granted by the license, users are provided only
# with a limited warranty  and the software's author,  the holder of the
# economic rights,  and the successive licensors  have only  limited
# liability.
#
# In this respect, the user's attention is drawn to the risks associated
# with loading,  using,  modifying and/or developing or reproducing the
# software by the user in light of its specific status of free software,
# that may mean  that it is complicated to manipulate,  and  that  also
# therefore means  that it is reserved for developers  and  experienced
# professionals having in-depth computer knowledge. Users are therefore
# encouraged to load and test the software's suitability as regards their
# requirements in conditions enabling the security of their systems and/or
# data to be ensured and,  more generally, to use and operate it in the
# same conditions as regards security.
#
# The fact that you are presently reading this means that you have had
# knowledge of the CeCILL license and that you accept its terms.

import dataclasses as dtcl
from typing import Any

from rich.text import Text as text_t

from conf_ini_g.extension.string import AlignedOnSeparator
from conf_ini_g.extension.type import NameValueTypeAsRichStr, TypeAsRichStr


@dtcl.dataclass(slots=True, repr=False, eq=False)
class annotation_t:
    def Issues(self) -> list[str]:
        """"""
        return []

    def ValueIsCompliant(self, _: Any, /) -> bool:
        """"""
        return True

    def __str__(self) -> str:
        """"""
        return text_t.from_markup(self.__rich__()).plain

    def __rich__(self) -> str:
        """"""
        output = [TypeAsRichStr(self)]

        names = (_fld.name for _fld in dtcl.fields(self))
        for name in names:
            value = getattr(self, name)
            output.append(f"    {NameValueTypeAsRichStr(name, value, separator='@=@')}")

        output = AlignedOnSeparator(output, "@=@", " = ")

        return "\n".join(output)
